@@ -93,6 +93,9 @@ struct sieve_binary_block;
 struct sieve_binary_debug_writer;
 struct sieve_binary_debug_reader;
 
+/* sieve-execute.h */
+struct sieve_execute;
+
 /* sieve-objects.h */
 struct sieve_object_def;
 struct sieve_object;
@@ -149,6 +152,12 @@ bool sieve_validate
 	(struct sieve_ast *ast, struct sieve_error_handler *ehandler,
 		enum sieve_compile_flags flags, enum sieve_error *error_r);
 
+/*
+ * Parent category
+ */
+
+extern struct event_category event_category_sieve;
+
 /*
  * Sieve engine instance
  */
@@ -176,7 +185,8 @@ struct sieve_instance {
 	const struct sieve_callbacks *callbacks;
 	void *context;
 
-	/* Engine debug */
+	/* Logging, events, and debug */
+	struct event *event;
 	bool debug;
 
 	/* Extension registry */
@@ -185,9 +195,6 @@ struct sieve_instance {
 	/* Storage class registry */
 	struct sieve_storage_class_registry *storage_reg;
 
-	/* System error handler */
-	struct sieve_error_handler *system_ehandler;
-
 	/* Plugin modules */
 	struct sieve_plugin *plugins;
 	enum sieve_env_location env_location;
@@ -223,6 +230,8 @@ const struct smtp_address *sieve_get_user_email
 
 const struct message_address *
 sieve_get_postmaster(const struct sieve_script_env *senv);
+const struct smtp_address *
+sieve_get_postmaster_smtp(const struct sieve_script_env *senv);
 const char *
 sieve_get_postmaster_address(const struct sieve_script_env *senv);
 
